@@ -7,7 +7,11 @@ use std::mem;
 use syn::__private::TokenStream2;
 use syn::fold::{fold_item, Fold};
 use syn::spanned::Spanned;
-use syn::{Item, ItemConst, ItemEnum, ItemExternCrate, ItemFn, ItemForeignMod, ItemImpl, ItemMacro, ItemMacro2, ItemMod, ItemStatic, ItemStruct, ItemTrait, ItemTraitAlias, ItemType, ItemUnion, ItemUse};
+use syn::{
+    Item, ItemConst, ItemEnum, ItemExternCrate, ItemFn, ItemForeignMod, ItemImpl, ItemMacro,
+    ItemMacro2, ItemMod, ItemStatic, ItemStruct, ItemTrait, ItemTraitAlias, ItemType, ItemUnion,
+    ItemUse,
+};
 
 mod attr;
 
@@ -76,17 +80,15 @@ fn process_programming_assignment(attributes: &[Attr], item: TokenStream) -> Tok
         .test()
         .map(|i| quote! {#(#i)*}.to_string())
         .unwrap_or_else(|| "".to_string());
-    let referencesolution = if let Some(i) = reference
-        .solution()
-        .map(|i| quote!{#(#i)*}.to_string())
-    {
-        i
-    } else {
-        return quote! {
-            compile_error!("assignment has no reference solution");
-        }
-        .into();
-    };
+    let referencesolution =
+        if let Some(i) = reference.solution().map(|i| quote! {#(#i)*}.to_string()) {
+            i
+        } else {
+            return quote! {
+                compile_error!("assignment has no reference solution");
+            }
+            .into();
+        };
     let solutiontemplate = template
         .solution()
         .map(|i| quote! {#(#i)*}.to_string())
@@ -101,7 +103,7 @@ fn process_programming_assignment(attributes: &[Attr], item: TokenStream) -> Tok
         }
     };
 
-    let description: String = attrs
+    let assignment_text = attrs
         .iter()
         .filter_map(|x| {
             if let Attr::Doc(i) = x {
@@ -110,9 +112,11 @@ fn process_programming_assignment(attributes: &[Attr], item: TokenStream) -> Tok
                 None
             }
         })
+        .map(|i| i.trim())
         .collect::<Vec<_>>()
         .join("\n");
 
+
     quote! {
         pub mod __WEBLAB_ASSIGNMENT_METADATA {
             use weblab::*;
@@ -120,7 +124,7 @@ fn process_programming_assignment(attributes: &[Attr], item: TokenStream) -> Tok
             pub const ASSIGNMENT_INFO: WeblabAssignment = WeblabAssignment::Programming(ProgrammingAssignment {
                 title: #title,
 
-                description: #description,
+                assignment_text: #assignment_text,
 
                 library_visible: false,
                 spectest_stdout_visible: false,
@@ -168,11 +172,9 @@ impl FindAnnotated {
                 Status::Maybe(i) => i.content.clone().map(|(_, x)| x),
                 Status::Unkown => None,
             },
-            FindAnnotated::Reference { test, .. } => test
-                .clone()
-                .map(|i| i.content.clone())
-                .flatten()
-                .map(|(_, x)| x),
+            FindAnnotated::Reference { test, .. } => {
+                test.clone().and_then(|i| i.content).map(|(_, x)| x)
+            }
         }
     }
 
@@ -183,22 +185,18 @@ impl FindAnnotated {
                 Status::Maybe(i) => i.content.clone().map(|(_, x)| x),
                 Status::Unkown => None,
             },
-            FindAnnotated::Reference { solution, .. } =>  solution
-                .clone()
-                .map(|i| i.content.clone())
-                .flatten()
-                .map(|(_, x)| x),
+            FindAnnotated::Reference { solution, .. } => {
+                solution.clone().and_then(|i| i.content).map(|(_, x)| x)
+            }
         }
     }
 
     pub fn library(&self) -> Option<Vec<Item>> {
         match self {
-            FindAnnotated::Template { library, .. } => library
-                .clone()
-                .map(|i| i.content.clone())
-                .flatten()
-                .map(|(_, x)| x),
-                FindAnnotated::Reference { .. } => None,
+            FindAnnotated::Template { library, .. } => {
+                library.clone().and_then(|i| i.content).map(|(_, x)| x)
+            }
+            FindAnnotated::Reference { .. } => None,
         }
     }
 
@@ -388,7 +386,7 @@ pub fn weblab(attr: TokenStream, item: TokenStream) -> TokenStream {
 
     let res = if let Some(Attr::ProgrammingAssignment) = attr.first() {
         process_programming_assignment(&attr[1..], item)
-    }  else {
+    } else {
         return syn::Error::new(
             Span::call_site().into(),
             "#[weblab(programming_assignment)] always needs to be the first attribute \
